// tslint:disable-next-line:no-var-requires
const ora = require('ora')('');
import chalk from 'chalk';

export class Stream {

    private output: NodeJS.WriteStream;
    private tab: string = '  ';

    constructor(output: NodeJS.WriteStream) {
        this.output = output;
    }

    public loading(text: string) {
        ora.text = text;
        ora.start();
    }

    public update(text: string) { 
        ora.text = text;
    }

    public stop() {
        ora.stopAndPersist();
    }

    public stopAndClear() {
        ora.stop();
    }

    public success(text?: string) {
        ora.succeed(text);
    }

    public done() {
        if (ora.text) {
            ora.stopAndPersist({ text: `${ora.text} done` });
        } else {
            ora.stopAndPersist();
        }
    }

    public ok(text: string) {
        ora.stopAndPersist({ text: `[OK] ${text}` });
    }

    public error(text: string | undefined) {
        if (!text) {
            ora.fail(text);
        } else {
            ora.stopAndPersist();
            ora.fail(text);
        }
    }

    public hint(text: string) {
        this.output.write(chalk.yellowBright(`i`) + ` ${text} \n`);
    }

    public print(text: string) {
        const indented = text.split('\n').map(l => this.tab + l).join('\n');
        this.output.write(indented + '\n');
    }

    public printNoLN(text: string) {
        const indented = text.split('\n').map(l => this.tab + l).join('\n');
        this.output.write(indented);
    }

    public log(tag: string, text: string) {
        this.print(`[${tag}] ${text}`);
    }
}
